@@ -10,22 +10,26 @@
 /* #undef HAVE_RINT */
 #define HAVE_TIMEGM
 
-#define HAVE_STD_ISNAN
+/* #undef HAVE_STD_ISNAN */
 #define HAVE_WORKING_STD_REGEX
 /* #undef HAVE_WINDOWS_H */
 #define HAVE_MKDTEMP
 /* #undef HAVE_AL_EXT_H */
-/* #undef HAVE_STD_INDEX_SEQUENCE */
-/* #undef HAVE_STD_REMOVE_CV_T */
+#define HAVE_STD_INDEX_SEQUENCE
+#define HAVE_STD_REMOVE_CV_T
 /* #undef HAVE_STD_REMOVE_CVREF_T */
-/* #undef HAVE_STD_ENABLE_IF_T */
-/* #undef HAVE_STD_BOOL_CONSTANT */
+#define HAVE_STD_ENABLE_IF_T
+#define HAVE_STD_BOOL_CONSTANT
 
 /* #undef GCC_ATOMIC_BUILTINS_FOUND */
 
+#define OPENVG
 #define SYSTEM_EXPAT
 #define ENABLE_SOUND
 /* #undef USE_AEONWAVE */
-/* #undef ENABLE_SIMD */
-/* #undef ENABLE_SIMD_CODE */
+/* #undef SG_SOUND_USES_OPENALSOFT */
+#define ENABLE_SIMD
 /* #undef ENABLE_GDAL */
+
+#define SIMGEAR_USING_CARES_DNS
+#define SG_FFMPEG
